@@ -422,6 +422,14 @@ def test(request):
     c['messages'] = []
     c.update(csrf(request))
     # Get some test data
+
+    if request.method == 'POST':
+        c['form'] = forms.PluginOutputForm(data=request.POST)
+        if c['form'].is_valid():
+            c['form'].parse()
+    else:
+        c['form'] = forms.PluginOutputForm(initial=request.GET)
+
     return render_to_response('test.html', c, context_instance=RequestContext(request))
 
 
@@ -476,4 +484,4 @@ def paste(request):
     else:
         c['form'] = forms.PasteForm(initial=request.GET)
 
-    return render_to_response('test2.html', c, context_instance=RequestContext(request))
\ No newline at end of file
+    return render_to_response('test2.html', c, context_instance=RequestContext(request))
